library(testthat)
library(googleLanguageR)

test_check("googleLanguageR")
